@@ -95,11 +95,10 @@ test_that(desc = "Testing plotResults functions", {
     expect_is(r4, c("gg","ggplot"))
   r5 <- plotCxdsResults(inSCE = sceres, reducedDimName="UMAP", sample = sampleVector, combinePlot = "all")
     expect_is(r5,  c("gg","ggplot"))
-  # Commenting out tests related to Bcds as that is producing errors in Bioc 3.22
-  #r6 <- plotBcdsResults(inSCE = sceres, reducedDimName="UMAP", sample = sampleVector, combinePlot = "all")
-  #  expect_is(r6,  c("gg","ggplot"))
-  #r7 <- plotScdsHybridResults(inSCE = sceres, reducedDimName="UMAP", sample = sampleVector, combinePlot = "all")
-  #  expect_is(r7,  c("gg","ggplot"))
+  r6 <- plotBcdsResults(inSCE = sceres, reducedDimName="UMAP", sample = sampleVector, combinePlot = "all")
+    expect_is(r6,  c("gg","ggplot"))
+  r7 <- plotScdsHybridResults(inSCE = sceres, reducedDimName="UMAP", sample = sampleVector, combinePlot = "all")
+    expect_is(r7,  c("gg","ggplot"))
   r8 <- plotDecontXResults(inSCE = sceres, reducedDimName="UMAP", sample = sampleVector, combinePlot = "all")
     expect_is(r8, c("gg","ggplot"))
 
